@@ -1,6 +1,6 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import warnings
 
-import matplotlib.pyplot as plt
 import mmcv
 import numpy as np
 import torch
@@ -36,7 +36,7 @@ def init_model(config, checkpoint=None, device='cuda:0', options=None):
     if checkpoint is not None:
         map_loc = 'cpu' if device == 'cpu' else None
         checkpoint = load_checkpoint(model, checkpoint, map_location=map_loc)
-        if 'CLASSES' in checkpoint['meta']:
+        if 'CLASSES' in checkpoint.get('meta', {}):
             model.CLASSES = checkpoint['meta']['CLASSES']
         else:
             from mmcls.datasets import ImageNet
@@ -89,7 +89,7 @@ def inference_model(model, img):
     return result
 
 
-def show_result_pyplot(model, img, result, fig_size=(15, 10)):
+def show_result_pyplot(model, img, result, fig_size=(15, 10), wait_time=0):
     """Visualize the classification results on the image.
 
     Args:
@@ -97,10 +97,11 @@ def show_result_pyplot(model, img, result, fig_size=(15, 10)):
         img (str or np.ndarray): Image filename or loaded image.
         result (list): The classification result.
         fig_size (tuple): Figure size of the pyplot figure.
+            Defaults to (15, 10).
+        wait_time (int): How many seconds to display the image.
+            Defaults to 0.
     """
     if hasattr(model, 'module'):
         model = model.module
-    img = model.show_result(img, result, show=False)
-    plt.figure(figsize=fig_size)
-    plt.imshow(mmcv.bgr2rgb(img))
-    plt.show()
+    model.show_result(
+        img, result, show=True, fig_size=fig_size, wait_time=wait_time)
