@@ -1,3 +1,4 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import warnings
 
 import numpy as np
@@ -7,8 +8,7 @@ from .base_dataset import BaseDataset
 
 
 class MultiLabelDataset(BaseDataset):
-    """ Multi-label Dataset.
-    """
+    """Multi-label Dataset."""
 
     def get_cat_ids(self, idx):
         """Get category ids by index.
