@@ -1,4 +1,6 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import copy
+import inspect
 import random
 from numbers import Number
 from typing import Sequence
@@ -9,12 +11,37 @@ import numpy as np
 from ..builder import PIPELINES
 from .compose import Compose
 
+# Default hyperparameters for all Ops
+_HPARAMS_DEFAULT = dict(pad_val=128)
+
 
 def random_negative(value, random_negative_prob):
     """Randomly negate value based on random_negative_prob."""
     return -value if np.random.rand() < random_negative_prob else value
 
 
+def merge_hparams(policy: dict, hparams: dict):
+    """Merge hyperparameters into policy config.
+
+    Only merge partial hyperparameters required of the policy.
+
+    Args:
+        policy (dict): Original policy config dict.
+        hparams (dict): Hyperparameters need to be merged.
+
+    Returns:
+        dict: Policy config dict after adding ``hparams``.
+    """
+    op = PIPELINES.get(policy['type'])
+    assert op is not None, f'Invalid policy type "{policy["type"]}".'
+    for key, value in hparams.items():
+        if policy.get(key, None) is not None:
+            continue
+        if key in inspect.getfullargspec(op.__init__).args:
+            policy[key] = value
+    return policy
+
+
 @PIPELINES.register_module()
 class AutoAugment(object):
     """Auto augmentation.
@@ -28,9 +55,12 @@ class AutoAugment(object):
             composed by several augmentations (dict). When AutoAugment is
             called, a random policy in ``policies`` will be selected to
             augment images.
+        hparams (dict): Configs of hyperparameters. Hyperparameters will be
+            used in policies that require these arguments if these arguments
+            are not set in policy dicts. Defaults to use _HPARAMS_DEFAULT.
     """
 
-    def __init__(self, policies):
+    def __init__(self, policies, hparams=_HPARAMS_DEFAULT):
         assert isinstance(policies, list) and len(policies) > 0, \
             'Policies must be a non-empty list.'
         for policy in policies:
@@ -41,7 +71,13 @@ class AutoAugment(object):
                     'Each specific augmentation must be a dict with key' \
                     ' "type".'
 
-        self.policies = copy.deepcopy(policies)
+        self.hparams = hparams
+        policies = copy.deepcopy(policies)
+        self.policies = []
+        for sub in policies:
+            merged_sub = [merge_hparams(policy, hparams) for policy in sub]
+            self.policies.append(merged_sub)
+
         self.sub_policy = [Compose(policy) for policy in self.policies]
 
     def __call__(self, results):
@@ -85,6 +121,9 @@ class RandAugment(object):
             - If 0 or negative number, magnitude remains unchanged.
             - If str "inf", magnitude is sampled from uniform distribution
               (range=[min, magnitude]).
+        hparams (dict): Configs of hyperparameters. Hyperparameters will be
+            used in policies that require these arguments if these arguments
+            are not set in policy dicts. Defaults to use _HPARAMS_DEFAULT.
 
     Note:
         `magnitude_std` will introduce some randomness to policy, modified by
@@ -103,7 +142,8 @@ class RandAugment(object):
                  num_policies,
                  magnitude_level,
                  magnitude_std=0.,
-                 total_level=30):
+                 total_level=30,
+                 hparams=_HPARAMS_DEFAULT):
         assert isinstance(num_policies, int), 'Number of policies must be ' \
             f'of int type, got {type(num_policies)} instead.'
         assert isinstance(magnitude_level, (int, float)), \
@@ -130,8 +170,10 @@ class RandAugment(object):
         self.magnitude_level = magnitude_level
         self.magnitude_std = magnitude_std
         self.total_level = total_level
-        self.policies = policies
-        self._check_policies(self.policies)
+        self.hparams = hparams
+        policies = copy.deepcopy(policies)
+        self._check_policies(policies)
+        self.policies = [merge_hparams(policy, hparams) for policy in policies]
 
     def _check_policies(self, policies):
         for policy in policies:
@@ -195,8 +237,8 @@ class Shear(object):
 
     Args:
         magnitude (int | float): The magnitude used for shear.
-        pad_val (int, tuple[int]): Pixel pad_val value for constant fill. If a
-            tuple of length 3, it is used to pad_val R, G, B channels
+        pad_val (int, Sequence[int]): Pixel pad_val value for constant fill.
+            If a sequence of length 3, it is used to pad_val R, G, B channels
             respectively. Defaults to 128.
         prob (float): The probability for performing Shear therefore should be
             in range [0, 1]. Defaults to 0.5.
@@ -219,7 +261,7 @@ class Shear(object):
             f'be int or float, but got {type(magnitude)} instead.'
         if isinstance(pad_val, int):
             pad_val = tuple([pad_val] * 3)
-        elif isinstance(pad_val, tuple):
+        elif isinstance(pad_val, Sequence):
             assert len(pad_val) == 3, 'pad_val as a tuple must have 3 ' \
                 f'elements, got {len(pad_val)} instead.'
             assert all(isinstance(i, int) for i in pad_val), 'pad_val as a '\
@@ -234,7 +276,7 @@ class Shear(object):
             f'should be in range [0,1], got {random_negative_prob} instead.'
 
         self.magnitude = magnitude
-        self.pad_val = pad_val
+        self.pad_val = tuple(pad_val)
         self.prob = prob
         self.direction = direction
         self.random_negative_prob = random_negative_prob
@@ -275,8 +317,8 @@ class Translate(object):
             the offset is calculated by magnitude * size in the corresponding
             direction. With a magnitude of 1, the whole image will be moved out
             of the range.
-        pad_val (int, tuple[int]): Pixel pad_val value for constant fill. If a
-            tuple of length 3, it is used to pad_val R, G, B channels
+        pad_val (int, Sequence[int]): Pixel pad_val value for constant fill.
+            If a sequence of length 3, it is used to pad_val R, G, B channels
             respectively. Defaults to 128.
         prob (float): The probability for performing translate therefore should
              be in range [0, 1]. Defaults to 0.5.
@@ -299,7 +341,7 @@ class Translate(object):
             f'be int or float, but got {type(magnitude)} instead.'
         if isinstance(pad_val, int):
             pad_val = tuple([pad_val] * 3)
-        elif isinstance(pad_val, tuple):
+        elif isinstance(pad_val, Sequence):
             assert len(pad_val) == 3, 'pad_val as a tuple must have 3 ' \
                 f'elements, got {len(pad_val)} instead.'
             assert all(isinstance(i, int) for i in pad_val), 'pad_val as a '\
@@ -314,7 +356,7 @@ class Translate(object):
             f'should be in range [0,1], got {random_negative_prob} instead.'
 
         self.magnitude = magnitude
-        self.pad_val = pad_val
+        self.pad_val = tuple(pad_val)
         self.prob = prob
         self.direction = direction
         self.random_negative_prob = random_negative_prob
@@ -362,8 +404,8 @@ class Rotate(object):
             the source image. If None, the center of the image will be used.
             Defaults to None.
         scale (float): Isotropic scale factor. Defaults to 1.0.
-        pad_val (int, tuple[int]): Pixel pad_val value for constant fill. If a
-            tuple of length 3, it is used to pad_val R, G, B channels
+        pad_val (int, Sequence[int]): Pixel pad_val value for constant fill.
+            If a sequence of length 3, it is used to pad_val R, G, B channels
             respectively. Defaults to 128.
         prob (float): The probability for performing Rotate therefore should be
             in range [0, 1]. Defaults to 0.5.
@@ -393,7 +435,7 @@ class Rotate(object):
             f'got {type(scale)} instead.'
         if isinstance(pad_val, int):
             pad_val = tuple([pad_val] * 3)
-        elif isinstance(pad_val, tuple):
+        elif isinstance(pad_val, Sequence):
             assert len(pad_val) == 3, 'pad_val as a tuple must have 3 ' \
                 f'elements, got {len(pad_val)} instead.'
             assert all(isinstance(i, int) for i in pad_val), 'pad_val as a '\
@@ -408,7 +450,7 @@ class Rotate(object):
         self.angle = angle
         self.center = center
         self.scale = scale
-        self.pad_val = pad_val
+        self.pad_val = tuple(pad_val)
         self.prob = prob
         self.random_negative_prob = random_negative_prob
         self.interpolation = interpolation
@@ -832,8 +874,8 @@ class Cutout(object):
         shape (int | float | tuple(int | float)): Expected cutout shape (h, w).
             If given as a single value, the value will be used for
             both h and w.
-        pad_val (int, tuple[int]): Pixel pad_val value for constant fill. If
-            it is a tuple, it must have the same length with the image
+        pad_val (int, Sequence[int]): Pixel pad_val value for constant fill.
+            If it is a sequence, it must have the same length with the image
             channels. Defaults to 128.
         prob (float): The probability for performing cutout therefore should
             be in range [0, 1]. Defaults to 0.5.
@@ -848,11 +890,16 @@ class Cutout(object):
             raise TypeError(
                 'shape must be of '
                 f'type int, float or tuple, got {type(shape)} instead')
+        if isinstance(pad_val, int):
+            pad_val = tuple([pad_val] * 3)
+        elif isinstance(pad_val, Sequence):
+            assert len(pad_val) == 3, 'pad_val as a tuple must have 3 ' \
+                f'elements, got {len(pad_val)} instead.'
         assert 0 <= prob <= 1.0, 'The prob should be in range [0,1], ' \
             f'got {prob} instead.'
 
         self.shape = shape
-        self.pad_val = pad_val
+        self.pad_val = tuple(pad_val)
         self.prob = prob
 
     def __call__(self, results):
