@@ -1,14 +1,15 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import warnings
 from abc import ABCMeta, abstractmethod
 from collections import OrderedDict
 
-import cv2
 import mmcv
 import torch
 import torch.distributed as dist
-from mmcv import color_val
 from mmcv.runner import BaseModule
 
+from mmcls.core.visualization import imshow_infos
+
 # TODO import `auto_fp16` from mmcv and delete them from mmcls
 try:
     from mmcv.runner import auto_fp16
@@ -168,10 +169,11 @@ class BaseClassifier(BaseModule, metaclass=ABCMeta):
     def show_result(self,
                     img,
                     result,
-                    text_color='green',
+                    text_color='white',
                     font_scale=0.5,
                     row_width=20,
                     show=False,
+                    fig_size=(15, 10),
                     win_name='',
                     wait_time=0,
                     out_file=None):
@@ -185,39 +187,29 @@ class BaseClassifier(BaseModule, metaclass=ABCMeta):
             row_width (int): width between each row of results on the image.
             show (bool): Whether to show the image.
                 Default: False.
+            fig_size (tuple): Image show figure size. Defaults to (15, 10).
             win_name (str): The window name.
-            wait_time (int): Value of waitKey param.
-                Default: 0.
+            wait_time (int): How many seconds to display the image.
+                Defaults to 0.
             out_file (str or None): The filename to write the image.
                 Default: None.
 
         Returns:
-            img (ndarray): Only if not `show` or `out_file`
+            img (ndarray): Image with overlayed results.
         """
         img = mmcv.imread(img)
         img = img.copy()
 
-        # write results on left-top of the image
-        x, y = 0, row_width
-        text_color = color_val(text_color)
-        for k, v in result.items():
-            if isinstance(v, float):
-                v = f'{v:.2f}'
-            label_text = f'{k}: {v}'
-            cv2.putText(img, label_text, (x, y), cv2.FONT_HERSHEY_COMPLEX,
-                        font_scale, text_color)
-            y += row_width
+        img = imshow_infos(
+            img,
+            result,
+            text_color=text_color,
+            font_size=int(font_scale * 50),
+            row_width=row_width,
+            win_name=win_name,
+            show=show,
+            fig_size=fig_size,
+            wait_time=wait_time,
+            out_file=out_file)
 
-        # if out_file specified, do not show image in window
-        if out_file is not None:
-            show = False
-
-        if show:
-            mmcv.imshow(img, win_name, wait_time)
-        if out_file is not None:
-            mmcv.imwrite(img, out_file)
-
-        if not (show or out_file):
-            warnings.warn('show==False and out_file is not specified, only '
-                          'result image will be returned')
-            return img
+        return img
